#!/usr/bin/python3
# -*- coding: utf-8 -*-

import sys
import os
import re

POLYGON = bool("polygon" in os.environ.get("APPDATA", "0").lower())

OK = 0
WA = 1
PE = 2
CF = 3

LOG = ""
sys.stdout.reconfigure(encoding='utf-8')
sys.stderr.reconfigure(encoding='utf-8')

# Формат ответа - одна строка, проверка при помощи регулярного выражения
ANSWER_REGEXP = "^[0123456789aAbB +\\-*/()\\u2212\\u0410\\u0411\\u0412\\u0430\\u0431\\u0432\\u0424\\u0444\\u0418\\u0438]+$"
# Ответ может состоять только из указанных символов, к сожалению, проверку корректности выражения не производим

def quit(status, log="", score=0):
    # Набранные баллы
    if POLYGON:
        sys.stdout.write(str(score) + " баллов; ")
    else:
        sys.stdout.write(str(score) + "\n")
    
    # Протокол проверки
    sys.stderr.write(log if log else LOG)
    
    # Статус
    sys.exit(status)


fin = open(sys.argv[2], "r", encoding="utf8")
ans = fin.readline().strip()

if re.compile(ANSWER_REGEXP).fullmatch(ans) is None:
    quit(PE, "В ответе используется недопустимый символ. Допускаются только буквы a и b, операции +, -, *, / и скобки ()")

ans = ans.lower()
ans = ans.replace(chr(0x0430), "a")  # русская "а"
ans = ans.replace(chr(0x0431), "b")  # русская "б"
ans = ans.replace(chr(0x0432), "b")  # русская "в"
ans = ans.replace(chr(0x0444), "a")  # русская "ф"
ans = ans.replace(chr(0x0438), "b")  # русская "и"
ans = ans.replace(chr(0x2212), "-")  # минус

if "//" in ans:
    quit(WA, "В ответе не может использоваться ''//''" + "\n")

if "**" in ans:
    quit(WA, "В ответе не может использоваться ''**''" + "\n")

ALL_PASSED = True

ANSWERS = {
    "(a + b) / 6": 100,
    "(a + b) / 3": 20,
    "(a + b) / 4": 20,
    "a + b / 6": 30,
    "b + a / 6": 30,
    "(a + b) * 2 / 3": 15,
    "(a+b)/5": 25,
    "(a-b)/6": 20,
    "(b-a)/6": 20,
    "a*b/6": 20,
    "(a+b)/b": 20,
    "(a+b)/8": 20,
    "(a+b)/6*5": 20,
    "(a+b)*6": 20,
    "(a+b)/2*3": 30,
    "(a+2*b)/6": 20,
    "(b+2*a)/6": 20,
    "a+b/2*3": 15,
    "b+a/2*3": 15,
    "(a+3*b)/6": 20,
    "(b+3*a)/6": 20,
    "((a / 2) + (b / 3)) / 3": 30,
    "((b / 2) + (a / 3)) / 3": 30,
    "(a+b)/-6": 40,
    "(a/2+b*2)/3": 30,
    "(b/2+a*2)/3": 30,
    "(a/2)-(2/3)*a-(b/3)": 10,
    "(b/2)-(2/3)*b-(a/3)": 10,
}

EPS = 1e-6
try:
    for i in range(2, 32):
        for j in range(1, i // 2 + 1):
            a = 2 * (i + j)
            b = 2 * (i + i - j)
            for sample in list(ANSWERS.keys()):
                if abs(eval(ans) - eval(sample)) > EPS:
                    del ANSWERS[sample]
except ZeroDivisionError as E:
    quit(WA, "При вычислении выражения возникло деление на ноль.\n", 0)
except Exception as E:
    quit(WA, "Некорректное арифметическое выражение.\n")

if len(ANSWERS) > 1:
    quit(CF, "Два подходящих варианта ответа в критериях оценивания.\n" + str(ANSWERS), 0)

if len(ANSWERS) == 0:
    quit(WA, "Это неправильный ответ\n", 0)

for sample in ANSWERS:
    if ANSWERS[sample] == 100:
        quit(OK, "Это правильный ответ\n", ANSWERS[sample])
    else:
        quit(WA, "Ответ эквивалентен выражению " + sample, ANSWERS[sample])
